==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AssigningScatterStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningScatterStyleEventArgsDescription } from "./AssigningScatterStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningScatterStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningScatterStyleEventArgsDescriptionMetadata, _super);
    function AssigningScatterStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningScatterStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningScatterStyleEventArgsDescriptionMetadata.a == null) {
            AssigningScatterStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningScatterStyleEventArgsDescriptionMetadata.c(AssigningScatterStyleEventArgsDescriptionMetadata.a);
        }
        if (a.g(AssigningScatterStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(AssigningScatterStyleEventArgsDescriptionMetadata.a);
    };
    AssigningScatterStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningScatterStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningScatterStyleEventArgsDescriptionMetadata.b(a);
        a.u("AssigningScatterStyleEventArgs", function () { return new AssigningScatterStyleEventArgsDescription(); });
        a.t("AssigningScatterStyleEventArgs", AssigningScatterStyleEventArgsDescriptionMetadata.a);
    };
    AssigningScatterStyleEventArgsDescriptionMetadata.$t = markType(AssigningScatterStyleEventArgsDescriptionMetadata, 'AssigningScatterStyleEventArgsDescriptionMetadata');
    AssigningScatterStyleEventArgsDescriptionMetadata.a = null;
    return AssigningScatterStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningScatterStyleEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AssigningScatterStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningScatterStyleEventArgsDescription } from "./AssigningScatterStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningScatterStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningScatterStyleEventArgsDescriptionMetadata, _super);
    function AssigningScatterStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningScatterStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningScatterStyleEventArgsDescriptionMetadata.a == null) {
            AssigningScatterStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningScatterStyleEventArgsDescriptionMetadata.c(AssigningScatterStyleEventArgsDescriptionMetadata.a);
        }
        if (a.j(AssigningScatterStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningScatterStyleEventArgsDescriptionMetadata.a);
    };
    AssigningScatterStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningScatterStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningScatterStyleEventArgsDescriptionMetadata.b(a);
        a.aa("AssigningScatterStyleEventArgs", function () { return new AssigningScatterStyleEventArgsDescription(); });
        a.z("AssigningScatterStyleEventArgs", AssigningScatterStyleEventArgsDescriptionMetadata.a);
    };
    AssigningScatterStyleEventArgsDescriptionMetadata.$t = markType(AssigningScatterStyleEventArgsDescriptionMetadata, 'AssigningScatterStyleEventArgsDescriptionMetadata');
    AssigningScatterStyleEventArgsDescriptionMetadata.a = null;
    return AssigningScatterStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningScatterStyleEventArgsDescriptionMetadata };
